@@ -102,7 +102,7 @@ def parse_event_xml(xml_event):
                         try:
                             value = from_didl_string(value)[0]
                         except SoCoException as original_exception:
-                            log.warning(
+                            log.debug(
                                 "Event contains illegal metadata"
                                 "for '%s'.\n"
                                 "Error message: '%s'\n"
@@ -302,7 +302,7 @@ class EventListenerBase:
             return
         self.is_running = False
         self.stop_listening(self.address)
-        log.info("Event Listener stopped")
+        log.debug("Event Listener stopped")
 
     # pylint: disable=missing-docstring
     def listen(self, ip_address):
@@ -443,7 +443,7 @@ class SubscriptionBase:
                 self.timeout = int(timeout.lstrip("Second-"))
             self._timestamp = time.time()
             self.is_subscribed = True
-            log.info(
+            log.debug(
                 "Subscribed to %s, sid: %s",
                 service.base_url + service.event_subscription_url,
                 self.sid,
@@ -492,7 +492,7 @@ class SubscriptionBase:
             log_msg = "Autorenewing subscription %s"
         else:
             log_msg = "Renewing subscription %s"
-        log.info(log_msg, self.sid)
+        log.debug(log_msg, self.sid)
 
         if self._has_been_unsubscribed:
             raise SoCoException("Cannot renew subscription once unsubscribed")
@@ -523,7 +523,7 @@ class SubscriptionBase:
                 self.timeout = int(timeout.lstrip("Second-"))
             self._timestamp = time.time()
             self.is_subscribed = True
-            log.info(
+            log.debug(
                 "Renewed subscription to %s, sid: %s",
                 self.service.base_url + self.service.event_subscription_url,
                 self.sid,
@@ -559,7 +559,7 @@ class SubscriptionBase:
 
         # pylint: disable=missing-docstring, unused-argument
         def success(*arg):
-            log.info(
+            log.debug(
                 "Unsubscribed from %s, sid: %s",
                 self.service.base_url + self.service.event_subscription_url,
                 self.sid,
@@ -597,7 +597,7 @@ class SubscriptionBase:
                 self.events.put(event)
             # pylint: disable=broad-except
             except Exception as ex:
-                log.debug("Error putting event %s, ex=%s", event, ex)
+                log.warning("Error putting event %s, ex=%s", event, ex)
 
     # pylint: disable=missing-docstring
     def _auto_renew_start(self, interval):
@@ -661,7 +661,7 @@ class SubscriptionBase:
         # Cancel any auto renew
         self._auto_renew_cancel()
         if msg:
-            log.info(msg)
+            log.debug(msg)
 
     @property
     def time_left(self):
